Async Elasticsearch API
=======================

 .. py:module:: elasticsearch
    :no-index:

 .. note::

    To reference Elasticsearch APIs that are namespaced like ``.indices.create()``
    refer to the sync API reference. These APIs are identical between sync and async.

Elasticsearch
-------------
 .. autoclass:: AsyncElasticsearch
   :members:
